@@ -4,6 +4,7 @@ from elasticsearch import NotFoundError, Elasticsearch
 from elasticsearch_dsl import Document, Integer, Keyword
 from .config_log import config
 from .config_log import log
+import json
 from .utils import drop_element_contain_in_str_list
 from .etl_time import make_timestamp
 from elasticsearch_dsl.query import Q, Match
@@ -321,19 +322,46 @@ class DocumentBase(Document):
         label = ''
 
 
-def getNerByEs(kw, es_model: Document, limit=40, key='name', reverse=True, case_sensitive=False):
+def _get_ner_key_type_str(kw, key, query_list, case_sensitive):
+    name_list = []
+    for x in query_list:
+        if not case_sensitive:
+            if x.get(key) and x.get(key).lower() in kw.lower(): name_list.append(x[key])
+        else:
+            if x.get(key) and x.get(key) in kw: name_list.append(x[key])
+    return name_list
+
+
+def _get_ner_key_type_list(kw, key, query_list, case_sensitive):
+    name_list = []
+    for item in query_list:
+        for x in json.loads(item[key]):
+            if not case_sensitive:
+                if x.lower() in kw.lower(): name_list.append(x)
+            else:
+                if x in kw: name_list.append(x)
+    return name_list
+
+
+def getNerByEs(kw, es_model, limit=40, key='name', key_type="str", reverse=True, case_sensitive=False):
+    """
+    :param kw: 输入的文本内容
+    :param es_model: 自定义的es model类
+    :param limit: 从es中查出前多少条数据进行分析
+    :param key: es document中的字段名称
+    :param key_type: es document中的字段存的是单个字符串还是字符串列表（json.dumps后的列表）
+    :param reverse: 识别出的实体是否按实体长度从大到小排序
+    :param case_sensitive: 大小写是否敏感，默认不区分大小写
+    :return:
+    """
     es_search = BaseSearcher(es_model.Index.using, doc_model=es_model)
     total, query_list = es_search.search_by_multi_bool(should=[Match(**{key: kw})], limit=limit)
     query_list = [r['_source'] for r in query_list]
 
-    name_list = []
-    for x in query_list:
-        if not case_sensitive:
-            if x.get(key) and x.get(key).lower() in kw.lower():
-                name_list.append(x[key])
-        else:
-            if x.get(key) and x.get(key) in kw:
-                name_list.append(x[key])
+    if key_type == 'list':
+        name_list = _get_ner_key_type_list(kw, key, query_list, case_sensitive)
+    else:
+        name_list = _get_ner_key_type_str(kw, key, query_list, case_sensitive)
 
     if not name_list: return {'origin_ner': name_list, 'merge_ner': name_list}
 
